@@ -3,7 +3,6 @@
 import datetime
 import glob
 import os
-import tempfile
 
 import nox
 
@@ -14,82 +13,6 @@ nox.options.sessions = ["lint", "test"]
 #
 # Helpers
 #
-def _install_this_project_with_flit(session, *, extras=None, editable=False):
-    session.install("flit")
-    args = []
-    if extras:
-        args.append("--extras")
-        args.append(",".join(extras))
-    if editable:
-        args.append("--pth-file" if os.name == "nt" else "--symlink")
-
-    session.run("flit", "install", "--deps=production", *args, silent=True)
-
-
-#
-# Development Sessions
-#
-@nox.session(name="docs-live", reuse_venv=True)
-def docs_live(session):
-    if session.posargs:
-        docs_dir = session.posargs[0]
-        additional_dependencies = session.posargs[1:]
-    else:
-        docs_dir = "docs/"
-        additional_dependencies = ()
-
-    build_command = "npx gulp build"
-    _install_this_project_with_flit(session, extras=["doc"], editable=True)
-    session.install("sphinx-autobuild", *additional_dependencies)
-
-    with tempfile.TemporaryDirectory() as destination:
-        session.run(
-            "sphinx-autobuild",
-            # for sphinx-autobuild
-            "--port=0",
-            "--watch=src/",
-            f"--pre-build={build_command}",
-            r"--re-ignore=src/.*/theme/furo/static/.*\.(css|js)",  # ignore the generated files
-            "--open-browser",
-            # for sphinx
-            "-b=dirhtml",
-            "-a",
-            docs_dir,
-            destination,
-        )
-
-
-@nox.session(reuse_venv=True)
-def docs(session):
-    # Generate relevant files prior to installation
-    session.run("npx", "gulp", "build", external=True)
-
-    _install_this_project_with_flit(session, extras=["doc"], editable=False)
-
-    # Generate documentation into `build/docs`
-    session.run("sphinx-build", "-b", "dirhtml", "-v", "docs/", "build/docs")
-
-
-@nox.session(reuse_venv=True)
-def lint(session):
-    session.install("pre-commit")
-
-    args = list(session.posargs)
-    args.append("--all-files")
-    if "CI" in os.environ:
-        args.append("--show-diff-on-failure")
-
-    session.run("pre-commit", "run", *args)
-
-
-@nox.session
-def test(session):
-    _install_this_project_with_flit(session, extras=["test"])
-
-    args = session.posargs or ["-n", "auto", "--cov", PACKAGE_NAME]
-    session.run("pytest", *args)
-
-
 def _determine_versions(current_version, date):
     """Returns (version_in_release, version_after_release)"""
     dev_num = int(current_version.rsplit(".dev", 1)[-1])
@@ -138,6 +61,46 @@ def get_release_versions(version_file):
     return _determine_versions(current_version, date=datetime.date.today())
 
 
+#
+# Development Sessions
+#
+@nox.session(reuse_venv=True)
+def docs(session):
+    # Generate relevant files prior to installation
+    session.install(".[doc]")
+
+    # Generate documentation into `build/docs`
+    session.run("sphinx-build", "-b", "dirhtml", "-v", "docs/", "build/docs")
+
+
+@nox.session(name="docs-live", reuse_venv=True)
+def docs_live(session):
+    session.install("-e", ".[doc]", "sphinx-theme-builder[cli]")
+
+    # Generate documentation into `build/docs`
+    session.run("stb", "serve", "docs/")
+
+
+@nox.session(reuse_venv=True)
+def lint(session):
+    session.install("pre-commit")
+
+    args = list(session.posargs)
+    args.append("--all-files")
+    if "CI" in os.environ:
+        args.append("--show-diff-on-failure")
+
+    session.run("pre-commit", "run", *args)
+
+
+@nox.session
+def test(session):
+    session.install("-e", ".[test]")
+
+    args = session.posargs or ["-n", "auto", "--cov", PACKAGE_NAME]
+    session.run("pytest", *args)
+
+
 @nox.session
 def release(session):
     version_file = f"src/{PACKAGE_NAME}/__init__.py"
@@ -147,7 +110,12 @@ def release(session):
 
     release_version, next_version = get_release_versions(version_file)
 
-    session.install("flit", "twine", "release-helper", "keyring")
+    session.install(
+        "keyring",
+        "release-helper",
+        "sphinx-theme-builder[cli]",
+        "twine",
+    )
 
     # Sanity Checks
     session.run("release-helper", "version-check-validity", release_version)
@@ -168,8 +136,7 @@ def release(session):
     )
 
     # Build the package
-    session.run("npx", "gulp", "build", external=True)
-    session.run("flit", "build")
+    session.run("stb", "package")
     session.run("twine", "check", *glob.glob("dist/*"))
 
     # Tag the commit
